"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const __1 = require("..");
const mockIntegration_1 = require("./mockIntegration");
// Test createAuthProvider function
describe('createAuthProvider', () => {
    let authProvider;
    beforeEach(() => {
        authProvider = (0, __1.createAuthProvider)(mockIntegration_1.mockIntegration);
    });
    it('should return a valid AuthProvider object', () => {
        expect(authProvider).toBeDefined();
        expect(authProvider.signIn).toBeDefined();
        expect(authProvider.signOut).toBeDefined();
        expect(authProvider.signUp).toBeDefined();
        expect(authProvider.lockAccount).toBeDefined();
        expect(authProvider.resetPassword).toBeDefined();
        expect(authProvider.confirmSignUp).toBeDefined();
        expect(authProvider.resendSignUp).toBeDefined();
        expect(authProvider.forgotPassword).toBeDefined();
        expect(authProvider.forgotPasswordConfirmationCode).toBeDefined();
        expect(authProvider.lockSession).toBeDefined();
        expect(authProvider.unlockSession).toBeDefined();
        expect(authProvider.unlockAccount).toBeDefined();
        expect(authProvider.disableAccount).toBeDefined();
        expect(authProvider.enableAccount).toBeDefined();
        expect(authProvider.refreshToken).toBeDefined();
        expect(authProvider.hasPermission).toBeDefined();
        expect(authProvider.definePermission).toBeDefined();
        expect(authProvider.validatePermission).toBeDefined();
        expect(authProvider.defineRole).toBeDefined();
        expect(authProvider.assignRole).toBeDefined();
        expect(authProvider.hasRole).toBeDefined();
        expect(authProvider.addCustomClaim).toBeDefined();
    });
    it('should call integration.signIn when signIn is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.signIn('username', 'password');
        expect(result.success).toBe(true);
    }));
    it('should update context when signin', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.signIn('username', 'password');
        expect(result.success).toBe(true);
        expect(authProvider.context.isAuthenticated).toBe(true);
        expect(authProvider.context.username).toBe("username");
        expect(authProvider.context.accessToken).toBe("accessToken");
        expect(authProvider.context.idToken).toBe("idToken");
        expect(authProvider.context.refreshToken).toBe("refreshToken");
    }));
    it('should call integration.signOut when signOut is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.signOut();
        expect(result.success).toBe(true);
    }));
    it('should call integration.signIn when signIn is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.signIn('username', 'password');
        expect(result.success).toBe(true);
    }));
    it('should call integration.signOut when signOut is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.signOut();
        expect(result.success).toBe(true);
    }));
    it('should call integration.signUp when signUp is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.signUp('username', 'password', 'email');
        expect(result.success).toBe(true);
    }));
    it('should call integration.lockAccount when lockAccount is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.lockAccount('username');
        expect(result.success).toBe(true);
    }));
    it('should call integration.resetPassword when resetPassword is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.resetPassword('username');
        expect(result.success).toBe(true);
    }));
    it('should call integration.confirmSignUp when confirmSignUp is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.confirmSignUp('username', 'code');
        expect(result.success).toBe(true);
    }));
    it('should call integration.resendSignUp when resendSignUp is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.resendSignUp('username');
        expect(result.success).toBe(true);
    }));
    it('should call integration.forgotPassword when forgotPassword is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.forgotPassword('username');
        expect(result.success).toBe(true);
    }));
    it('should call integration.forgotPasswordConfirmationCode when forgotPasswordConfirmationCode is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.forgotPasswordConfirmationCode('username', 'code', 'newPassword');
        expect(result.success).toBe(true);
    }));
    it('should call integration.signIn when signIn is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const integration = mockIntegration_1.mockIntegration;
        const authProvider = (0, __1.createAuthProvider)(integration);
        expect(yield authProvider.signIn('username', 'password')).toStrictEqual({
            success: true,
        });
    }));
    it('should call integration.signOut when signOut is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const integration = mockIntegration_1.mockIntegration;
        const authProvider = (0, __1.createAuthProvider)(integration);
        expect(yield authProvider.signOut()).toStrictEqual({ success: true });
    }));
    it('should call integration.lockSession when lockSession is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.lockSession();
        expect(result.success).toBe(true);
    }));
    it('should call integration.unlockSession when unlockSession is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.unlockSession();
        expect(result.success).toBe(true);
    }));
    it('should call integration.unlockAccount when unlockAccount is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.unlockAccount('username');
        expect(result.success).toBe(true);
    }));
    it('should call integration.disableAccount when disableAccount is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.disableAccount('username');
        expect(result.success).toBe(true);
    }));
    it('should call integration.enableAccount when enableAccount is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.enableAccount('username');
        expect(result.success).toBe(true);
    }));
    it('should call integration.refreshToken when refreshToken is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.refreshToken();
        expect(result.success).toBe(true);
    }));
    it('should call integration.hasPermission when hasPermission is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.hasPermission('permission');
        expect(result).toBe(true);
    }));
    it('should call integration.definePermission when definePermission is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.definePermission('permission');
        expect(result.success).toBe(true);
    }));
    it('should call integration.validatePermission when validatePermission is called', () => {
        const result = authProvider.validatePermission('permission');
        expect(result).toBe(true);
    });
    it('should call integration.defineRole when defineRole is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.defineRole('role', [
            'permission',
        ]);
        expect(result.success).toBe(true);
    }));
    it('should call integration.assignRole when assignRole is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.assignRole('username', 'role');
        expect(result.success).toBe(true);
    }));
    it('should call integration.hasRole when hasRole is called', () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield authProvider.hasRole('username', 'role');
        expect(result).toBe(true);
    }));
    it('should call integration.addCustomClaim when addCustomClaim is called', () => {
        authProvider.addCustomClaim('claim', 'value');
        // You can add assertions related to custom claim handling here
    });
});
